#!/usr/bin/env python3

import requests

if __name__ == '__main__':
  headers = {'Content-Type': 'application/json'}
  response = requests.post('http://localhost:8080/process', headers=headers, json={"test":"value"}, verify=False)
  response.raise_for_status()
  print(response.url)
  print(str(response.status_code) + ": " + response.json())
